@@ -2,7 +2,6 @@ package integration
 
 import (
 	"io/fs"
-	"io/ioutil"
 	"os"
 	"testing"
 
@@ -90,7 +89,7 @@ func TestBasic_RoutesInputsToProperOutputs(t *testing.T) {
 		assert.NilError(t, err)
 		m := iohelpers.NormalizeFileMode(v.mode)
 		assert.Equal(t, m, info.Mode(), v.path)
-		content, err := ioutil.ReadFile(v.path)
+		content, err := os.ReadFile(v.path)
 		assert.NilError(t, err)
 		assert.Equal(t, v.content, string(content))
 	}
@@ -210,7 +209,7 @@ func TestBasic_RoutesInputsToProperOutputsWithChmod(t *testing.T) {
 		info, err := os.Stat(v.path)
 		assert.NilError(t, err)
 		assert.Equal(t, iohelpers.NormalizeFileMode(v.mode), info.Mode())
-		content, err := ioutil.ReadFile(v.path)
+		content, err := os.ReadFile(v.path)
 		assert.NilError(t, err)
 		assert.Equal(t, v.content, string(content))
 	}
@@ -238,7 +237,7 @@ func TestBasic_OverridesOutputModeWithChmod(t *testing.T) {
 		info, err := os.Stat(v.path)
 		assert.NilError(t, err)
 		assert.Equal(t, iohelpers.NormalizeFileMode(v.mode), info.Mode())
-		content, err := ioutil.ReadFile(v.path)
+		content, err := os.ReadFile(v.path)
 		assert.NilError(t, err)
 		assert.Equal(t, v.content, string(content))
 	}
@@ -258,7 +257,7 @@ func TestBasic_AppliesChmodBeforeWrite(t *testing.T) {
 	info, err := os.Stat(out)
 	assert.NilError(t, err)
 	assert.Equal(t, iohelpers.NormalizeFileMode(0644), info.Mode())
-	content, err := ioutil.ReadFile(out)
+	content, err := os.ReadFile(out)
 	assert.NilError(t, err)
 	assert.Equal(t, "hi\n", string(content))
 }
@@ -272,7 +271,7 @@ func TestBasic_CreatesMissingDirectory(t *testing.T) {
 	info, err := os.Stat(out)
 	assert.NilError(t, err)
 	assert.Equal(t, iohelpers.NormalizeFileMode(0640), info.Mode())
-	content, err := ioutil.ReadFile(out)
+	content, err := os.ReadFile(out)
 	assert.NilError(t, err)
 	assert.Equal(t, "hi\n", string(content))
 
